@@ -11,6 +11,7 @@ def main():
                version : 0.1.2 pitv  \n                                              \
                actions:\n                                                      \
                status        status pitv \n  \
+               evacuate      evacuate this computer \n  \
                \
                2023 Knowit Miracle\
                ")
@@ -26,29 +27,3 @@ def main():
     if args.action[0] == "status":
         print("status pitv")
         pitv.status()
-
-
-    if args.action[0] == "list_datasets":
-        print("list_datasets pitv")
-        pitv.list_datasets()
-    
-    if args.action[0] == "delete_all_datasets":
-        print("delete_all_datasets pitv")
-        pitv.delete_all_datasets()
-        
-
-    if args.action[0] == "delete_all_dags":
-        print("delete_all_dags pitv")
-        pitv.delete_all_dags()
-
-
-    if args.action[0] == "set":
-        print("set pitv")
-        pitv.set()
-
-    if args.action[0] == "list_dags":
-        print("list_dags pitv")
-        pitv.list_dags()
-
-
-
